#This script will get the process IDs for the VIX Viewer, Render and Tomcat services
#It will stop and restart each service and then generate a log file to email to admins

#This outputs everything to a file to troubleshoot"
#$myTimestamp = Get-Date -Format 'yyyyMMdd.hhmmss'
#Start-Transcript -path "C:\Program Files\VistA\Imaging\Scripts\p249_vix_services_output.txt"

$tomcatname = "Tomcat8"
$viewername = "VIX Viewer Service"
$rendername = "VIX Render Service"
$listenername = "ListenerTool"

#Shut down and restart Tomcat Service
#Pre-shutdown statuses
$tomcatpid = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$tomcatname'" | Select-Object -ExpandProperty ProcessId
$tomcatstatus = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$tomcatname'" | Select-Object -ExpandProperty Status
$tomcatstate = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$tomcatname'" | Select-Object -ExpandProperty State
echo "***** Tomcat8 Service *****"
echo "Tomcat PID:  $tomcatpid"
echo $tomcatstatus
echo $tomcatstate


#check state
#if "Running", proceed to shutdown.  if not log and alert.
if ($tomcatstate -eq 'Running') {
	echo "$tomcatname service is running.  Stopping service..."
	Stop-Service -Name "$tomcatname" -Force
	#verifying service stopped
	Start-Sleep -s 10
	$tomcatstate2 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$tomcatname'" | Select-Object -ExpandProperty State
	echo "$tomcatname is $tomcatstate2"
	if ($tomcatstate2 -eq 'Stopped') {
		echo "tomcat service successfully stopped.  Restarting service..."
		Start-Service -Name "$tomcatname"
		#verifying service started
		Start-Sleep -s 10
		$tomcatstate3 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$tomcatname'" | Select-Object -ExpandProperty State
		echo "$tomcatname is $tomcatstate3"
		if ($tomcatstate3 -eq 'Running') {
		echo "tomcat service successfully restarted."
		}
	}
} else {
	echo "$tomcatname is not running.  That's not good."
	$V_emailstatus = "$tomcatname was not running.  Check Event Log for details."
	echo "Attempting to start $tomcatname service.  Starting service..."
	Start-Service -Name "$tomcatname"
	#verifying service started
	Start-Sleep -s 10
	$tomcatstate3 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$tomcatname'" | Select-Object -ExpandProperty State
	echo "$tomcatname is $tomcatstate3"
	if ($tomcatstate3 -eq 'Running') {
		echo "tomcat service successfully restarted."
	}	
}
#Post-restart statuses
$prs_tomcatpid = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$tomcatname'" | Select-Object -ExpandProperty ProcessId
$prs_tomcatstatus = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$tomcatname'" | Select-Object -ExpandProperty Status
$prs_tomcatstate = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$tomcatname'" | Select-Object -ExpandProperty State
echo "-NEW- tomcat PID:  $prs_tomcatpid"
echo $prs_tomcatstatus
echo $prs_tomcatstate
echo "**********"


#Shut down and restart VIX Viewer Service
#Pre-shutdown statuses
$viewerpid = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$viewername'" | Select-Object -ExpandProperty ProcessId
$viewerstatus = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$viewername'" | Select-Object -ExpandProperty Status
$viewerstate = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$viewername'" | Select-Object -ExpandProperty State
echo "***** VIX Viewer Service *****"
echo "Viewer PID:  $viewerpid"
echo $viewerstatus
echo $viewerstate

#check state
#if "Running", proceed to shutdown.  if not log and alert.
if ($viewerstate -eq 'Running') {
	echo "Viewer service is running.  Stopping service..."
	Stop-Service -Name "$viewername" -Force
	#verifying service stopped
	Start-Sleep -s 10
	$viewerstate2 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$viewername'" | Select-Object -ExpandProperty State
	echo "$viewername is $viewerstate2"
	if ($viewerstate2 -eq 'Stopped') {
		echo "Viewer service successfully stopped.  Checking for orphaned processes..."
		$viewerprocs = (Get-Process | Where-Object {$_.Name -eq 'Hydra.VistA.Worker'}).count
		echo "Viewer process count: $viewerprocs"
		if ($viewerprocs -gt 0) {
			echo "There are existing orphaned processes."
			echo "Killing orphans...so sad."
			Stop-Process -Name "Hydra.VistA.Worker" -Force
		}
		
		Start-Sleep -s 5
		echo "Restarting service..."
		Start-Service -Name "$viewername"
		#verifying service started
		Start-Sleep -s 10
		$viewerstate3 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$viewername'" | Select-Object -ExpandProperty State
		echo "$viewername is $viewerstate3"
		if ($viewerstate3 -eq 'Running') {
		echo "Viewer service successfully restarted."
		}
	}
} else {
	echo "$viewername is not running.  That's not good."
	echo "Looking for orphan processes..."
	$viewerprocs = (Get-Process | Where-Object {$_.Name -eq 'Hydra.VistA.Worker'}).count
	echo "Viewer process count: $viewerprocs"
	if ($viewerprocs -gt 0) {
		echo "There are existing orphaned processes."
		echo "Killing orphans...so sad."
		Stop-Process -Name "Hydra.VistA.Worker" -Force
	}
	
	$V_emailstatus = "$viewername was not running.  Check Event Log for details."
	echo "Attempting to start $viewername service.  Starting service..."
	Start-Service -Name "$viewername"
	#verifying service started
	Start-Sleep -s 10
	$viewerstate3 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$viewername'" | Select-Object -ExpandProperty State
	echo "$viewername is $viewerstate3"
	if ($viewerstate3 -eq 'Running') {
		echo "Viewer service successfully restarted."
	}	
}
#Post-restart statuses
$prs_viewerpid = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$viewername'" | Select-Object -ExpandProperty ProcessId
$prs_viewerstatus = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$viewername'" | Select-Object -ExpandProperty Status
$prs_viewerstate = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$viewername'" | Select-Object -ExpandProperty State
echo "-NEW- Viewer PID:  $prs_viewerpid"
echo $prs_viewerstatus
echo $prs_viewerstate
echo "**********"


#Shut down and restart VIX Render Service
#Pre-shutdown statuses
$renderpid = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$rendername'" | Select-Object -ExpandProperty ProcessId
$renderstatus = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$rendername'" | Select-Object -ExpandProperty Status
$renderstate = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$rendername'" | Select-Object -ExpandProperty State
echo "***** VIX Render Service *****"
echo "Render PID:  $renderpid"
echo $renderstatus
echo $renderstate

#check state
#if "Running", proceed to shutdown.  if not log and alert.
if ($renderstate -eq 'Running') {
	echo "Render service is running.  Stopping service..."
	Stop-Service -Name "$rendername" -Force
	#verifying service stopped
	Start-Sleep -s 10
	$renderstate2 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$rendername'" | Select-Object -ExpandProperty State
	echo "$rendername is $renderstate2"
	
	if ($renderstate2 -eq 'Stopped') {
		echo "Render service successfully stopped.  Checking for orphaned processes..."
		$renderprocs = (Get-Process | Where-Object {$_.Name -eq 'Hydra.IX.Processor'}).count
		echo "Render process count: $renderprocs"
		if ($renderprocs -gt 0) {
			echo "There are existing orphaned processes."
			echo "Killing orphans...so sad."
			Stop-Process -Name "Hydra.IX.Processor" -Force
		}
		
		Start-Sleep -s 5
		echo "Restarting service..."
		Start-Service -Name "$rendername"
		#verifying service started
		Start-Sleep -s 10
		$renderstate3 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$rendername'" | Select-Object -ExpandProperty State
		echo "$rendername is $renderstate3"
		if ($renderstate3 -eq 'Running') {
		echo "Render service successfully restarted."
		}
	}
} else {
	echo "$rendername is not running.  That's not good."
	echo "Looking for orphan processes..."
	$renderprocs = (Get-Process | Where-Object {$_.Name -eq 'Hydra.IX.Processor'}).count
	echo "Render process count: $renderprocs"
	if ($renderprocs -gt 0) {
		echo "There are existing orphaned processes."
		echo "Killing orphans...so sad."
		Stop-Process -Name "Hydra.IX.Processor" -Force
	}
	
	$V_emailstatus = "$rendername was not running.  Check Event Log for details."
	echo "Attempting to start $rendername service.  Starting service..."
	Start-Service -Name "$rendername"
	#verifying service started
	Start-Sleep -s 10
	$renderstate3 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$rendername'" | Select-Object -ExpandProperty State
	echo "$rendername is $renderstate3"
	if ($renderstate3 -eq 'Running') {
		echo "Viewer service successfully restarted."
	}	
}
#Post-restart statuses
$prs_renderpid = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$rendername'" | Select-Object -ExpandProperty ProcessId
$prs_renderstatus = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$rendername'" | Select-Object -ExpandProperty Status
$prs_renderstate = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$rendername'" | Select-Object -ExpandProperty State
echo "-NEW- Render PID:  $prs_renderpid"
echo $prs_renderstatus
echo $prs_renderstate
echo "**********"


#Shut down and restart Listener Tool Service
#Pre-shutdown statuses
$listenerpid = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$listenername'" | Select-Object -ExpandProperty ProcessId
$listenerstatus = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$listenername'" | Select-Object -ExpandProperty Status
$listenerstate = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$listenername'" | Select-Object -ExpandProperty State
echo "***** ListenerTool Service *****"
echo "Listener PID:  $listenerpid"
echo $listenerstatus
echo $listenerstate

#check state
#if "Running", proceed to shutdown.  if not log and alert.
if ($listenerstate -eq 'Running') {
	echo "Listener service is running.  Stopping service..."
	Stop-Service -Name "$listenername" -Force
	#verifying service stopped
	Start-Sleep -s 10
	$listenerstate2 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$listenername'" | Select-Object -ExpandProperty State
	echo "$listenername is $listenerstate2"
	if ($listenerstate2 -eq 'Stopped') {
		echo "Listener service successfully stopped.  Restarting service..."
		Start-Service -Name "$listenername"
		#verifying service started
		Start-Sleep -s 10
		$listenerstate3 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$listenername'" | Select-Object -ExpandProperty State
		echo "$listenername is $listenerstate3"
		if ($listenerstate3 -eq 'Running') {
		echo "Listener service successfully restarted."
		}
	}
} else {
	echo "$listenername is not running.  That's not good."
	$V_emailstatus = "$listenername was not running.  Check Event Log for details."
	echo "Attempting to start $listenername service.  Starting service..."
	Start-Service -Name "$listenername"
	#verifying service started
	Start-Sleep -s 10
	$listenerstate3 = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$listenername'" | Select-Object -ExpandProperty State
	echo "$listenername is $listenerstate3"
	if ($listenerstate3 -eq 'Running') {
		echo "Listener service successfully restarted."
	}	
}

#Post-restart statuses
$prs_listenerpid = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$listenername'" | Select-Object -ExpandProperty ProcessId
$prs_listenerstatus = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$listenername'" | Select-Object -ExpandProperty Status
$prs_listenerstate = Get-WmiObject -Class Win32_Service -Filter "Name LIKE '$listenername'" | Select-Object -ExpandProperty State
echo "-NEW- Listener PID:  $prs_listenerpid"
echo $prs_listenerstatus
echo $prs_listenerstate
echo "**********"

#gathering statuses and emailing logs to admins
#Stop-Transcript

echo "***** DONE *****"