﻿If (-NOT ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator))
{
  # Relaunch as an elevated process:
  Start-Process powershell.exe "-File",('"{0}"' -f $MyInvocation.MyCommand.Path) -Verb RunAs
  exit
}

function Check-AT-User {
    Clear-Host
    $ErrorActionPreference = 'Stop'
    $VerbosePreference = 'Continue'

    #User to search for
    $USERNAME = "apachetomcat"

    #Declare LocalUser Object
    $ObjLocalUser = $null

	# Check for user
    Try {
        Write-Host "Searching for $($USERNAME) in LocalUser DataBase"
        $ObjLocalUser = Get-LocalUser $USERNAME
        Write-Host "User $($USERNAME) was found"
    }

    Catch [Microsoft.PowerShell.Commands.UserNotFoundException] {
        "User $($USERNAME) was not found" | Write-Warning
        "Please make sure to install the latest VIX MAG release" | Write-Warning
        Exit
    }

    Catch {
        "An unspecifed error occured" | Write-Error
        Exit # Stop Powershell! 
    }
}

function Set-AT-GroupMembership {
    $ErrorActionPreference = 'Stop'
    $VerbosePreference = 'Continue'

    #User to search for
    $USERNAME = "apachetomcat"
    $GROUPNAME = "Users"

    #Declare LocalUser Object
    $ObjLocalGroupMember = $null

	# Check for local user in group
    Try {
        Write-Host "Searching for $($USERNAME) in LocalGroupMember DataBase"
        $ObjLocalGroupMember = Get-LocalGroupMember -Group $GROUPNAME -Member $USERNAME
        Write-Host "User $($USERNAME) was found"
    }

    Catch [Microsoft.PowerShell.Commands.PrincipalNotFoundException] {
        "User $($USERNAME) was not found" | Write-Warning
        "Please make sure to install the latest VIX MAG release" | Write-Warning
        Exit
    }

    Catch {
        "An unspecifed error occured" | Write-Error
        Exit # Stop Powershell! 
    }


	# Add local user to group
    Try {
        Write-Host "Adding $($USERNAME) to Local Group $GROUPNAME"
        $ObjLocalGroupMember = Add-LocalGroupMember -Group $GROUPNAME -Member $USERNAME
        Write-Host "User $($USERNAME) was successfully added to $GROUPNAME"
    }

    Catch [Microsoft.PowerShell.Commands.PrincipalNotFoundException] {
        "User $($USERNAME) was not found" | Write-Warning
        "Please make sure to install the latest VIX MAG release" | Write-Warning
        Exit
    }

    Catch [Microsoft.PowerShell.Commands.GroupNotFoundException] {
        "Group $($GROUPNAME) was not found" | Write-Warning
        "This is a serious issue.  Contact support." | Write-Warning
        Exit
    }

    Catch [Microsoft.PowerShell.Commands.MemberExistsException] {
        "User $($USERNAME) already exists in Group $($GROUPNAME)" | Write-Warning
        "Continuing to edit folder permissions..." | Write-Warning
    }

    Catch {
        "An unspecifed error occured" | Write-Error
        Exit # Stop Powershell! 
    }
}


function Set-AT-FolderPermissions {

	# Creating array of folder locations
	$dcfPath = "C:\DCF_RunTime_x64"
	$vixPath = "C:\VixConfig"
	$tomcatPath = "C:\Program Files\Apache Software Foundation\Tomcat 8.0"
	$javaPath = "C:\Program Files\Java\jre1.8.0_202"
	$allPaths = @("$($dcfPath)", "$($vixPath)", "$($tomcatPath)", "$($javaPath)")
    
    foreach ($path in $allPaths)
    {
        $ErrorActionPreference = 'Stop'
        $VerbosePreference = 'Continue'

        #User to search for
        $USERNAME = "apachetomcat"

        #Declare LocalUser Object
        $ObjLocalUser = $null

	    # Check for user
        Try {
            Write-Host "`n****************************************"
            Write-Host "*** Searching for $($USERNAME) permissions in $($path)"
            Write-Host "****************************************"

            $ObjLocalUser = (Get-Acl "$path").Access | ?{$_.IdentityReference -like "*$USERNAME"} | Select IdentityReference,FileSystemRights
            if ($ObjLocalUser -ne $null)
            {
                Write-Host "       USER:  $($ObjLocalUser.IdentityReference)"
                Write-Host "PERMISSIONS:  $($ObjLocalUser.FileSystemRights)"
            } else {
                Write-Host "No User Permissions Found"
            }

            Write-Host "--- Setting File Permissions"
            
            $Rights = "Modify"
	        $InheritSettings = "Containerinherit, ObjectInherit"
	        $PropogationSettings = "None"
	        $RuleType = "Allow"

	        $acl = Get-Acl $path
	        $perm = $USERNAME, $Rights, $InheritSettings, $PropogationSettings, $RuleType
	        $rule = New-Object -TypeName System.Security.AccessControl.FileSystemAccessRule -ArgumentList $perm
	        $acl.SetAccessRule($rule)
	        $acl | Set-Acl -Path $path
            
            Write-Host "--- File Permissions Edits Complete"
            Write-Host "--- Verifying Permissions Edits"

            $ObjLocalUser = (Get-Acl "$path").Access | ?{$_.IdentityReference -like "*$USERNAME"} | Select IdentityReference,FileSystemRights
            if ($ObjLocalUser -ne $null)
            {
                Write-Host "       USER:  $($ObjLocalUser.IdentityReference)"
                Write-Host "PERMISSIONS:  $($ObjLocalUser.FileSystemRights)"
            } else {
                Write-Host "No User Permissions Found"
            }
        }

        Catch [Microsoft.PowerShell.Commands.UserNotFoundException] {
            "User $($USERNAME) was not found" | Write-Warning
            "Please make sure to install the latest VIX MAG release" | Write-Warning
            Exit
        }

        Catch {
            "An unspecifed error occured" | Write-Error
            Exit # Stop Powershell! 
        }

    }

}


Set-AT-GroupMembership
Set-AT-FolderPermissions

Pause