# Patch 249 VIX Config Editor
# File location for pre-install backups
$preRenderFile = "C:\VixConfig\PreInstall\P249\VIX.Render.config"
$preViewerFile = "C:\VixConfig\PreInstall\P249\VIX.Viewer.config"
$preServerFile = "C:\VixConfig\PreInstall\P249\server.xml"
$preMuseFile = "C:\VixConfig\PreInstall\P249\MuseDataSource-1.0.Config"

# File location for critical files
$renderFile = "C:\Program Files\VistA\Imaging\VIX.Config\VIX.Render.config"
$viewerFile = "C:\Program Files\VistA\Imaging\VIX.Config\VIX.Viewer.config"
$serverFile = "C:\Program Files\Apache Software Foundation\Tomcat 8.0\conf\server.xml"
$museFile = "C:\VixConfig\MuseDataSource-1.0.Config"

$patchString = "<!-- Changed in MAG*3.0*249 - $($myDate) -->"

Write-Host "getting computer name..."
$myname = (Get-WmiObject win32_computersystem).DNSHostName+"."+(Get-WmiObject win32_computersystem).Domain
Write-Host "computer name: $myname"

$myTimestamp = Get-Date -Format 'yyyyMMdd.HHmmss'
Write-Host $myTimestamp

$backupFiles = @($renderFile, $viewerFile, $serverFile, $museFile)

foreach ($backup in $backupFiles)
{
    Write-Host "Backing up $($backup) ..."

    $destFile = "$($backup)_$($myTimestamp)"

    Copy-Item "$($backup)" "$($destFile)"
    if (Test-Path "$($destFile)") {
	    Write-Host "backup successful"
    } else {
	    Write-Host "backup failed!!!!"
    }
}

Write-Host "***** Editing VIX.Render.config File *****"
Write-Host "copying pre-install backup..."
Copy-Item "$($preRenderFile)" "$($renderFile)"
Write-Host "setting string variables..."
$varTiffOld = "ConvertTiffToPdf"
$varTiffNew = "    <Processor WorkerPoolSize=`"10`" UseSeparateProcess=`"true`" ReprocessFailedImages=`"false`" ConvertTiffToPdf=`"true`" MaxPagesTiffToPdf=`"75`" OpTimeOutMins=`"5`">"
$varTiffNewTotal = "    $($patchString)`n$($varTiffNew)"
Write-Host $varTiffOld
Write-Host $varTiffNew

Write-Host "Checking to see if file actually needs to be edited"
if (Get-Content $($renderFile) | Where-Object {$_ -like "*$($varTiffNew)*"}) {
	Write-Host "P249 TIFF edit found, edit aborted."
} else {
	Write-Host "P249 TIFF edit not found.  Proceeding with VIX.Render.config edit."

    Write-Host "search and replace..."
    $tiffLine = Get-Content $($renderFile) | Select-String $($varTiffOld) | Select-Object -ExpandProperty Line
    $tiffLineNumber = Get-Content $($renderFile) | Select-String $($varTiffOld) | Select-Object -ExpandProperty LineNumber
    $myline = $($tiffLine)
    $mylinenumber = $($tiffLineNumber) - 1
    Write-Host "This is the line to be replaced:  $($myline)"
    Write-Host "This is the line number to be replaced:  $($mylinenumber)"

    $newServiceLine = Get-Content $($renderFile)
    $newServiceLine[$($mylinenumber)] = $($varTiffNewTotal)
    $newServiceLine | Set-Content $($renderFile)

    Write-Host "validating edit was successful..."
    if (Get-Content $($renderFile) | Where-Object {$_ -like "*$($varTiffNew)*"}) {
	    Write-Host "New TIFF Edit Found"
    } else {
	    Write-Host "New TIFF Edit Not Found!!!!"
    }
}

Write-Host "***** Editing VIX.Viewer.config File *****"
Write-Host "copying pre-install backup..."
Copy-Item "$($preViewerFile)" "$($viewerFile)"
Write-Host "setting string variables..."
$varServiceOld = "VixService ServiceType=`"Viewer`""
$varServiceNew = "      <VixService ServiceType=`"Viewer`" RootUrl=`"https://+:343`" PublicHostName=`"$($myname)`" TrustedClientRootUrl=`"https://+:344`" />"
$varServiceNewTotal = "      $($patchString)`n$($varServiceNew)"
Write-Host $varServiceOld
Write-Host $varServiceNew

Write-Host "Checking to see if file actually needs to be edited"
if (Get-Content $($viewerFile) | Where-Object {$_ -like "*$($varServiceNew)*"}) {
	Write-Host "P249 HTTPS edit found, edit aborted."
} else {
	Write-Host "P249 HTTPS edit not found.  Proceeding with VIX.Viewer.config edit."

    Write-Host "search and replace..."
    $serviceLine = Get-Content $($viewerFile) | Select-String $($varServiceOld) | Select-Object -ExpandProperty Line
    $serviceLineNumber = Get-Content $($viewerFile) | Select-String $($varServiceOld) | Select-Object -ExpandProperty LineNumber
    $myline = $($serviceLine)
    $mylinenumber = $($serviceLineNumber) - 1
    Write-Host "This is the line to be replaced:  $($myline)"
    Write-Host "This is the line number to be replaced:  $($mylinenumber)"

    $newServiceLine = Get-Content $($viewerFile)
    $newServiceLine[$($mylinenumber)] = $($varServiceNewTotal)
    $newServiceLine | Set-Content $($viewerFile)

    Write-Host "validating edit was successful..."
    if (Get-Content $($viewerFile) | Where-Object {$_ -like "*$($varServiceNew)*"}) {
	    Write-Host "New HTTPS Edit Found"
    } else {
	    Write-Host "New HTTPS Edit Not Found!!!!"
    }
}

Write-Host "***** Restoring Pre-Install Tomcat Server File *****"
Write-Host "copying pre-install backup..."
Copy-Item "$($preServerFile)" "$($serverFile)"

Write-Host "***** Restoring Pre-Install Muse Config File *****"
Write-Host "copying pre-install backup..."
Copy-Item "$($preMuseFile)" "$($museFile)"
echo "edit complete"

#echo "***** Sending Confirmation Email *****"
#Send-MailMessage -From "vixhost1@domain" -To "chad.bigler@domain" -Subject "MAG*3.0*249 $($myname) VIX Install Report" -Body "config files attached" -SmtpServer "smtp.office365.gov" -Attachments $($myVCF)


<#
echo "create COM object named Outlook"
$Outlook = New-Object -ComObject Outlook.Application
echo "create Outlook MailItem named Mail using CreateItem() method"
$Mail = $Outlook.CreateItem(0)
echo "add properties as desired"
$Mail.To = "chad.bigler@domain"
$Mail.Subject = "MAG*3.0*249 $($myname) VIX Install Report"
$Mail.Body = "Install report attached."
echo "send message"
$Mail.Send()
echo "quit and cleanup"
$Outlook.Quit()
[System.Runtime.Interopservices.Marshal]::ReleaseComObject($Outlook) | Out-Null
#>

echo "DONE"