# Patch 249 Pre-Installation VIX Config Backup
If (-NOT ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator))
{
  # Relaunch as an elevated process:
  Start-Process powershell.exe "-File",('"{0}"' -f $MyInvocation.MyCommand.Path) -Verb RunAs
  exit
}


function Get-ConfigBackups {

	# File location for pre-install backups
	$precfgPath = "C:\VixConfig\PreInstall\P249"
	if(!(Test-Path -path $precfgPath))  
	{  
		New-Item -ItemType directory -Path $precfgPath
		Write-Host "Folder path has been created successfully at: " $precfgPath               
	}

	# File location for critical files
	$renderFile = "C:\Program Files\VistA\Imaging\VIX.Config\VIX.Render.config"
	$viewerFile = "C:\Program Files\VistA\Imaging\VIX.Config\VIX.Viewer.config"
	$serverFile = "C:\Program Files\Apache Software Foundation\Tomcat 8.0\conf\server.xml"
	$cacheFIle = "C:\VixConfig\cache-config\ImagingExchangeCache-cache.xml"
	$museFile = "C:\VixConfig\MuseDataSource-1.0.Config"

	echo "getting computer name..."
	$myname = (Get-WmiObject win32_computersystem).DNSHostName+"."+(Get-WmiObject win32_computersystem).Domain
	echo "computer name: $myname"

	$myTimestamp = Get-Date -Format 'yyyyMMdd.HHmmss'
	echo $myTimestamp

	$patchString = "p249_preinstall_$($myTimestamp)" #not currently used
	$backupFiles = @($renderFile, $viewerFile, $serverFile, $museFile, $cacheFile)

	foreach ($backup in $backupFiles)
	{
		Write-Host "Backing up $($backup) ..."

		$destFile = "$($precfgPath)\$($backup.split('\')[-1])"

		Copy-Item "$($backup)" "$($destFile)"
		if (Test-Path "$($destFile)") {
			echo "backup successful"
		} else {
			echo "backup failed!!!!"
		}
	}
}


echo "DONE"